#!/usr/bin/env sh

## Config
if [ ! -f "/srv/app/personalsite/settings.py" ]; then
    # generate config
    cat > /srv/app/personalsite/settings.py <<- EOF
"""
Django settings for personalsite project.

Generated by 'django-admin startproject' using Django 2.1.2.

For more information on this file, see
https://docs.djangoproject.com/en/2.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.1/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '${SECRET_KEY:-8$oylik7o2-dbx+5a77=2a532w8lx&=ofiyv!1bs9a9)0t%6r2}'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = ${APP_DEBUG:-False}

ALLOWED_HOSTS = ["${WEB_SITE_URL:-example.com}", "localhost", "127.0.0.1", "0.0.0.0", "django"]


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'core',
    'project.apps.ProjectConfig',
    'social.apps.SocialConfig',
    'django_cleanup.apps.CleanupConfig',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'personalsite.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'social.processors.ctx_dict',
            ],
        },
    },
]

WSGI_APPLICATION = 'personalsite.wsgi.application'


# Database
# https://docs.djangoproject.com/en/2.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': '${NAME_DB:-site}',
        'USER': '${USER_DB:-site}',
        'PASSWORD': '${PASS_DB:-site}',
        'HOST': '${HOST_DB:-127.0.0.1}',
        'PORT': '${PORT_DB:-5432}',
    }
}

# Password validation
# https://docs.djangoproject.com/en/2.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/2.1/topics/i18n/

LANGUAGE_CODE = 'es'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.1/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(BASE_DIR, 'static')

# Media files
MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')

# Incoming Email
EMAIL_FROM = '${EMAIL_FROM:-noreply@example.com}'
EMAIL_TO = '${EMAIL_TO:-user@example.com}'

# Email config
EMAIL_HOST = '${EMAIL_HOST:-smtp.example.com}'
EMAIL_HOST_USER = '${EMAIL_HOST_USER:-username}'
EMAIL_HOST_PASSWORD = '${EMAIL_HOST_PASSWORD:-password}'
EMAIL_PORT = '${EMAIL_HOST_PORT:-587}'
EMAIL_USE_TLS = ${EMAIL_USE_TLS:-True}
EOF
fi

mkdir -p /srv/app/core/static/core/css || true
sassc -t compressed /srv/app/core/static/core/sass/estilos.sass /srv/app/core/static/core/css/estilos.min.css
cd /srv/app || exit
/usr/local/bin/python3 manage.py makemigrations --no-input
/usr/local/bin/python3 manage.py migrate --no-input
/usr/local/bin/python3 manage.py collectstatic --no-input

gunicorn -b "0.0.0.0:${GUNICORN_PORT_NUMBER:-8080}" --timeout "${GUNICORN_TIMEOUT:-30}" --workers "${GUNICORN_NUM_WORKERS:-4}" personalsite.wsgi &
exec nginx -g "daemon off;"
